@@ -10,7 +10,10 @@ response.
 13
 
 """
-from collections import OrderedDict
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 
 class SolrResponse(object):
     """ Parse solr response and make it accesible."""
@@ -92,4 +95,4 @@ def parse_spellcheck(solr_suggestions):
             result[key] = value
 
     result['suggestions'] = suggestions
-    return result
\ No newline at end of file
+    return result
